==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/SimpleWorkflow/WorkflowExecutionFilter.pm <==
package Paws::SimpleWorkflow::WorkflowExecutionFilter;
  use Moose;
  has WorkflowId => (is => 'ro', isa => 'Str', request_name => 'workflowId', traits => ['NameInRequest'], required => 1);
1;

### main pod documentation begin ###

=head1 NAME

Paws::SimpleWorkflow::WorkflowExecutionFilter

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::SimpleWorkflow::WorkflowExecutionFilter object:

  $service_obj->Method(Att1 => { WorkflowId => $value, ..., WorkflowId => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::SimpleWorkflow::WorkflowExecutionFilter object:

  $result = $service_obj->Method(...);
  $result->Att1->WorkflowId

=head1 DESCRIPTION

Used to filter the workflow executions in visibility APIs by their
C<workflowId>.

=head1 ATTRIBUTES


=head2 B<REQUIRED> WorkflowId => Str

  The workflowId to pass of match the criteria of this filter.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::SimpleWorkflow>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.40.tar.gz: Paws-0.40/lib/Paws/SimpleWorkflow/WorkflowExecutionFilter.pm <==
package Paws::SimpleWorkflow::WorkflowExecutionFilter;
  use Moose;
  has WorkflowId => (is => 'ro', isa => 'Str', request_name => 'workflowId', traits => ['NameInRequest'], required => 1);
1;

### main pod documentation begin ###

=head1 NAME

Paws::SimpleWorkflow::WorkflowExecutionFilter

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::SimpleWorkflow::WorkflowExecutionFilter object:

  $service_obj->Method(Att1 => { WorkflowId => $value, ..., WorkflowId => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::SimpleWorkflow::WorkflowExecutionFilter object:

  $result = $service_obj->Method(...);
  $result->Att1->WorkflowId

=head1 DESCRIPTION

Used to filter the workflow executions in visibility APIs by their
C<workflowId>.

=head1 ATTRIBUTES


=head2 B<REQUIRED> WorkflowId => Str

  The workflowId to pass of match the criteria of this filter.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::SimpleWorkflow>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
